@@ -1,5 +1,5 @@
 /* ReaPack: Package manager for REAPER
- * Copyright (C) 2015-2024  Christian Fillion
+ * Copyright (C) 2015-2025  Christian Fillion
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -29,6 +29,8 @@
 #include "transaction.hpp"
 #include "win32.hpp"
 
+#include <algorithm>
+
 enum Timers { TIMER_FILTER = 1, TIMER_ABOUT };
 
 Browser::Browser()
@@ -216,7 +218,7 @@ void Browser::onCommand(const int id, const int event)
 
 bool Browser::onKeyDown(const int key, const int mods)
 {
-  if(GetFocus() != m_list->handle()) {
+  if(GetFocus() != m_list->handle() && GetFocus() != m_view) {
     if(mods == 0 && (key == VK_UP || key == VK_DOWN))
       SetFocus(m_list->handle());
 
@@ -322,6 +324,7 @@ void Browser::displayButton()
     {"&Automation Items",  Package::AutomationItemType},
     {"&Effects",           Package::EffectType},
     {"E&xtensions",        Package::ExtensionType},
+    {"&Key Maps",          Package::KeymapType},
     {"&Language Packs",    Package::LangPackType},
     {"&MIDI Note Names",   Package::MIDINoteNamesType},
     {"&Project Templates", Package::ProjectTemplateType},
@@ -372,6 +375,7 @@ bool Browser::isFiltered(Package::Type type) const
 
   switch(type) {
   case Package::UnknownType:
+  // user-selectable types
   case Package::ScriptType:
   case Package::EffectType:
   case Package::ExtensionType:
@@ -382,7 +386,9 @@ bool Browser::isFiltered(Package::Type type) const
   case Package::TrackTemplateType:
   case Package::MIDINoteNamesType:
   case Package::AutomationItemType:
+  case Package::KeymapType:
     break;
+  // "other packages"
   case Package::DataType:
     type = Package::UnknownType;
     break;
