@@ -1,5 +1,5 @@
 /* ReaPack: Package manager for REAPER
- * Copyright (C) 2015-2024  Christian Fillion
+ * Copyright (C) 2015-2025  Christian Fillion
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -32,6 +32,8 @@
 #include "transaction.hpp"
 #include "win32.hpp"
 
+#include <algorithm>
+
 static const Win32::char_type *ARCHIVE_FILTER =
   L("ReaPack Offline Archive (*.ReaPackArchive)\0*.ReaPackArchive\0");
 static const Win32::char_type *ARCHIVE_EXT = L("ReaPackArchive");
@@ -694,6 +696,12 @@ void NetworkConfig::onInit()
 
   m_staleThreshold = getControl(IDC_STALETHRSH);
   setChecked(m_opts->staleThreshold > 0, m_staleThreshold);
+
+  m_fallbackProxy = getControl(IDC_FALLBCKPXY);
+  if(boost::logic::indeterminate(m_opts->fallbackProxy))
+    hide(m_fallbackProxy);
+  else
+    setChecked(static_cast<bool>(m_opts->fallbackProxy), m_fallbackProxy);
 }
 
 void NetworkConfig::onCommand(const int id, int)
@@ -714,4 +722,6 @@ void NetworkConfig::apply()
   m_opts->verifyPeer = isChecked(m_verifyPeer);
   m_opts->staleThreshold = isChecked(m_staleThreshold)
     ? NetworkOpts::OneWeekThreshold : NetworkOpts::NoThreshold;
+  if(isVisible(m_fallbackProxy))
+    m_opts->fallbackProxy = isChecked(m_fallbackProxy);
 }
